@@ -24,6 +24,6 @@ SOFTWARE.'''
 
 """aiodagpi - An asynchronous python API wrapper for Dagpi : https://dagpi.xyz"""
 
-__version__ = '0.3.0'
+__version__ = '0.3.1'
 __author__ = 'Raj Sharma <yrsharma@icloud.com>'
-__all__ = ['aiodagpiclient']
+__all__ = []
