@@ -25,7 +25,8 @@ from .exceptions import InvalidOption, InvalidToken, RateLimited, ServerError, U
 
 
 class Http:
-
+    """Base aiodagpi http class
+    """
     def __init__(self, token) -> None:
         self.token = token
         self.session = None
