@@ -20,10 +20,14 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.'''
 
-class Object(object):
+
+class Object():
+    """The base aiodagpi object class
+    """
     def __init__(self, **entries):
         self.__dict__.update(entries)
 
-def MakeObject(data:dict) -> Object:
-    Obj = Object(**data)
-    return Obj
+
+def Make_Object(data: dict) -> Object:
+    Final = Object(**data)
+    return Final
